<?php

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	class WC_Product_Loops_Settings {

		public static function init() {
			add_action( 'admin_enqueue_scripts', __CLASS__ . '::scripts', 9 );
		}

		public static function scripts() {
				wp_register_script( 'product-loops', Wcmnpl()->plugin_url() . '/assets/js/admin.js', array( 'jquery' ), Wcmnpl()->version(), true );
				wp_enqueue_script( 'product-loops' );
		}

		public static function get_settings( $plugins ) {

			$plugins['product_loops'] = array(
				'slug' => 'product_loops',
				'name' => esc_html__( 'Product Loops for WooCommerce', 'product-loops' ),
				'desc' => esc_html__( 'Settings page for Product Loops for WooCommerce!', 'product-loops' ),
				'link' => 'https://mihajlovicnenad.com/product/product-loops-woocommerce/',
				'imgs' => Wcmnpl()->plugin_url(),
				'ref' => array(
					'name' => esc_html__( 'More plugins and themes?', 'product-loops' ),
					'url' => 'https://mihajlovicnenad.com/shop/'
				),
				'doc' => array(
					'name' => esc_html__( 'Documentation and Plugin Guide', 'product-loops' ),
					'url' => 'https://mihajlovicnenad.com/product-loops-woocommerce/documentation-and-guide/'
				),
				'sections' => array(
					'dashboard' => array(
						'name' => esc_html__( 'Dashboard', 'autopilot-seo' ),
						'desc' => esc_html__( 'Dashboard Overview', 'autopilot-seo' ),
					),
					'presets' => array(
						'name' => esc_html__( 'Product Loops', 'product-loops' ),
						'desc' => esc_html__( 'Product Loop Options', 'product-loops' ),
					),
					'loops' => array(
						'name' => esc_html__( 'Assign Product Loops', 'product-loops' ),
						'desc' => esc_html__( 'Assign Product Loop Options', 'product-loops' ),
					),
					'quickview' => array(
						'name' => esc_html__( 'Product Quickview', 'product-loops' ),
						'desc' => esc_html__( 'Product Quickview Options', 'product-loops' ),
					),
					'installation' => array(
						'name' => esc_html__( 'Installation', 'product-loops' ),
						'desc' => esc_html__( 'Installation Options', 'product-loops' ),
					),
				),
				'settings' => array(

					'wcmn_dashboard' => array(
						'type' => 'html',
						'id' => 'wcmn_dashboard',
						'desc' => '
						<img src="' . Wcmnpl()->plugin_url() . '/assets/images/product-loops-for-woocommerce-shop.png" class="svx-dashboard-image" />
						<h3 style="margin-top: 0;"><span class="dashicons dashicons-store"></span> Get plugins and themes</h3><p>Like what you see? Improve your shop even more! Use our standardized items in your Shop today and earn more. Get <a href="https://www.mihajlovicnenad.com" target="_blank">Mihajlovicnenad.com</a> plugins and themes <a href="https://www.mihajlovicnenad.com/shop/" target="_blank">here</a>.</p>
						<h3><span class="dashicons dashicons-welcome-learn-more"></span> Knowledge Base</h3><p>Find everything about <a href="https://www.mihajlovicnenad.com" target="_blank">Mihajlovicnenad.com</a> plugins and themes in our <a href="https://www.mihajlovicnenad.com/knowledge-base/" target="_blank">Knowledge Base</a>. In-depth documentation for the items, including dozens of guide videos and plugin information.</p>
						<h3><span class="dashicons dashicons-admin-tools"></span> Support</h3><p>Need support? Please use one of the support channels provided <a href="https://www.mihajlovicnenad.com/support/" target="_blank">here</a>. If you have valid support, use the Premium Support and click the Connect with Envato. Open a ticket and an agent will reply asap. Further, use the Community Forums to get help from the community.</p>
						<h3><span class="dashicons dashicons-update"></span> Automatic Updates</h3><p>To get automatic updates use the Envato Market plugin! Install this simple plugin, and you will be noted about the new updates right in your WordPress Dashboard! Get Envato Market plugin <a href="https://envato.com/market-plugin/" target="_blank">here</a>.</p>',
						'section' => 'dashboard',
					),

					'wcmn_utility' => array(
						'name' => esc_html__( 'Plugin Options', 'autopilot-seo' ),
						'type' => 'utility',
						'id' => 'wcmn_utility',
						'desc' => esc_html__( 'Quick export/import, backup and restore, or just reset your optons here', 'autopilot-seo' ),
						'section' => 'dashboard',
					),

					'wcmn_pl_presets' => array(
						'name' => esc_html__( 'Loop Manager', 'product-loops' ),
						'type' => 'list',
						'id'   => 'wcmn_pl_presets',
						'desc' => esc_html__( 'Create product loop presets', 'product-loops' ),
						'autoload' => false,
						'section' => 'presets',
						'title' => esc_html__( 'Loop Name', 'product-loops' ),
						'options' => 'list',
						'ajax_options' => 'ajax:wp_options:_wcmn_pl_preset_%NAME%',
						'settings' => array(

							'name' => array(
								'name' => esc_html__( 'Loop Name', 'product-loops' ),
								'type' => 'text',
								'id' => 'name',
								'desc' => esc_html__( 'Enter loop name', 'product-loops' ),
								'default' => '',
							),

							'loop' => array(
								'name' => esc_html__( 'Loop Type', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Select loop type', 'product-loops' ),
								'id'   => 'loop',
								'options' => array(
									'loop-1' => esc_html__( 'Classic', 'product-loops' ),
									'loop-2' => esc_html__( 'Elegant', 'product-loops' ),
									'loop-3' => esc_html__( 'Boxed', 'product-loops' ),
									'loop-4' => esc_html__( 'Boxed and Colored', 'product-loops' ),
									'loop-5' => esc_html__( 'Inside bottom', 'product-loops' ),
									'loop-6' => esc_html__( 'Inside bottom with Meta/Options hover', 'product-loops' ),
									'loop-7' => esc_html__( 'Inside top', 'product-loops' ),
									'loop-8' => esc_html__( 'Inside top with Meta/Options hover', 'product-loops' ),
									'loop-9' => esc_html__( 'Inside top with Meta/Options slide in from bottom', 'product-loops' ),
									'loop-10' => esc_html__( 'Outside with hover', 'product-loops' ),
								),
								'default' => 'loop-1',
								'class' => ''
							),

							'mode' => array(
								'name' => esc_html__( 'Default Display', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Select default display mode', 'product-loops' ),
								'id'   => 'mode',
								'options' => array(
									'grid' => esc_html__( 'Grid', 'product-loops' ),
									'table' => esc_html__( 'List', 'product-loops' ),
								),
								'default' => 'grid',
								'class' => ''
							),

							'button' => array(
								'name' => esc_html__( 'Button', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Set button style', 'product-loops' ),
								'id'   => 'button',
								'options' => array(
									'none' => esc_html__( 'Inherit from theme', 'product-loops' ),
									'flat' => esc_html__( 'Flat', 'product-loops' ),
									'flat3d' => esc_html__( 'Flat 3D', 'product-loops' ),
									'hue' => esc_html__( 'Hue', 'product-loops' ),
									'hue3d' => esc_html__( 'Hue 3D', 'product-loops' ),
								),
								'default' => 'hue',
								'class' => '',
								'column' => '3'
							),

							'accent_color' => array(
								'name' => esc_html__( 'Accent Color', 'product-loops' ),
								'type' => 'text',
								'id' => 'accent_color',
								'desc' => esc_html__( 'Set loop accent color', 'product-loops' ),
								'default' => '#007ae5',
								'class' => 'svx-color',
								'column' => '3'
							),

							'hover_color' => array(
								'name' => esc_html__( 'Hover Color', 'product-loops' ),
								'type' => 'text',
								'id' => 'hover_color',
								'desc' => esc_html__( 'Set loop hover color', 'product-loops' ),
								'default' => '#5000e5',
								'class' => 'svx-color',
								'column' => '3 last'
							),

							'size' => array(
								'name' => esc_html__( 'Image Size', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Set image size', 'product-loops' ),
								'id'   => 'size',
								'options' => 'ajax:image_sizes',
								'default' => 'shop_catalog',
								'class' => '',
								'column' => '2'
							),

							'ratio' => array(
								'name' => esc_html__( 'Image Ratio', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Set image ratio', 'product-loops' ),
								'id'   => 'ratio',
								'options' => array(
									'none' => esc_html__( 'Use WooCommerce image size', 'product-loops' ) . ' (shop_catalog)',
									'full' => esc_html__( 'Full Resolution', 'product-loops' ) . ' (full)',
									'large' => esc_html__( 'Large WordPress', 'product-loops' ) . ' (large)',
									'medium' => esc_html__( 'Medium WordPress', 'product-loops' ) . ' (medium)',
									'1-1' => '1 : 1',
									'2-1' => '2 : 1',
									'1-2' => '1 : 2',
									'3-1' => '3 : 1',
									'1-3' => '1 : 3',
									'4-3' => '4 : 3',
									'3-4' => '3 : 4',
									'16-9' => '16 : 9',
									'9-16' => '9 : 16',
									'5-3' => '5 : 3',
									'3-5' => '3 : 5',
								),
								'default' => 'none',
								'class' => '',
								'column' => '2 last'
							),

							'align' => array(
								'name' => esc_html__( 'Image Align', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Set image align', 'product-loops' ),
								'id'   => 'align',
								'options' => array(
									'start' => esc_html__( 'Starting point', 'product-loops' ),
									'center' => esc_html__( 'Center', 'product-loops' ),
									'end' => esc_html__( 'Ending point', 'product-loops' ),
								),
								'default' => 'start',
								'class' => '',
								'column' => '2'
							),

							'effect' => array(
								'name' => esc_html__( 'Image Effect', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Set  image effect', 'product-loops' ),
								'id'   => 'effect',
								'options' => array(
									'none' => esc_html__( 'None', 'product-loops' ),
									'gallery' => esc_html__( 'Image gallery', 'product-loops' ),
									'fade' => esc_html__( 'Fade in second image', 'product-loops' ),
									'slide-up' => esc_html__( 'Slide up second image', 'product-loops' ),
									'slide-down' => esc_html__( 'Slide down second image', 'product-loops' ),
									'slide-left' => esc_html__( 'Slide left second image', 'product-loops' ),
									'slide-right' => esc_html__( 'Slide right second image', 'product-loops' ),
									'zoom-in' => esc_html__( 'Zoom in second image', 'product-loops' ),
									'fade-overlay' => esc_html__( 'Fade in overlay', 'product-loops' ),
									'slide-up-overlay' => esc_html__( 'Slide up overlay', 'product-loops' ),
									'slide-down-overlay' => esc_html__( 'Slide down overlay', 'product-loops' ),
									'slide-left-overlay' => esc_html__( 'Slide left overlay', 'product-loops' ),
									'slide-right-overlay' => esc_html__( 'Slide right overlay', 'product-loops' ),
									'zoom-in-overlay' => esc_html__( 'Zoom in overlay', 'product-loops' )
								),
								'default' => 'none',
								'class' => '',
								'column' => '2 last'
							),

							'excerpt_grid' => array(
								'name' => esc_html__( 'Grid Description Rows', 'product-loops' ),
								'type' => 'number',
								'desc' => esc_html__( 'Set the product short description row length in grid mode', 'product-loops' ),
								'id'   => 'excerpt_grid',
								'default' => 1,
								'column' => '2'
							),

							'excerpt_table' => array(
								'name' => esc_html__( 'List Description Rows', 'product-loops' ),
								'type' => 'number',
								'desc' => esc_html__( 'Set the product short description row length in list mode', 'product-loops' ),
								'id'   => 'excerpt_table',
								'default' => 3,
								'column' => '2 last'
							),

							'hide_grid' => array(
								'name' => esc_html__( 'Grid Elements', 'product-loops' ),
								'type' => 'multiselect',
								'desc' => esc_html__( 'Select loop elements to hide in grid mode', 'product-loops' ),
								'id'   => 'hide_grid',
								'options' => array(
									'img' => esc_html__( 'Product Image', 'product-loops' ),
									'ttl' => esc_html__( 'Product Title', 'product-loops' ),
									'dsc' => esc_html__( 'Product Short Description', 'product-loops' ),
									'mta' => esc_html__( 'Product Meta', 'product-loops' ),
									'atr' => esc_html__( 'Product Attributes', 'product-loops' ),
									'prc' => esc_html__( 'Product Price', 'product-loops' ),
									'add' => esc_html__( 'Product Add to Cart', 'product-loops' ),
									'qck' => esc_html__( 'Quickview', 'product-loops' ),
								),
								'default' => array(),
								'class'   => 'svx-selectize',
								'column' => '2'
							),

							'hide_table' => array(
								'name' => esc_html__( 'List Elements', 'product-loops' ),
								'type' => 'multiselect',
								'desc' => esc_html__( 'Select loop elements to hide in list mode', 'product-loops' ),
								'id'   => 'hide_table',
								'options' => array(
									'img' => esc_html__( 'Product Image', 'product-loops' ),
									'ttl' => esc_html__( 'Product Title', 'product-loops' ),
									'dsc' => esc_html__( 'Product Short Description', 'product-loops' ),
									'mta' => esc_html__( 'Product Meta', 'product-loops' ),
									'atr' => esc_html__( 'Product Attributes', 'product-loops' ),
									'prc' => esc_html__( 'Product Price', 'product-loops' ),
									'add' => esc_html__( 'Product Add to Cart', 'product-loops' ),
									'qck' => esc_html__( 'Quickview', 'product-loops' ),
								),
								'default' => array(),
								'class' => 'svx-selectize',
								'column' => '2 last'
							),

							'meta_grid' => array(
								'name' => esc_html__( 'Grid Meta', 'product-loops' ),
								'type' => 'multiselect',
								'desc' => esc_html__( 'Select meta elements to hide in grid mode', 'product-loops' ),
								'id'   => 'meta_grid',
								'options' => array(
									'sales' => esc_html__( 'Sales', 'product-loops' ),
									'author' => esc_html__( 'Author', 'product-loops' ),
									'date' => esc_html__( 'Date', 'product-loops' ),
									'category' => esc_html__( 'Category', 'product-loops' ),
									'tags' => esc_html__( 'Tag', 'product-loops' ),
									'sku' => esc_html__( 'SKU', 'product-loops' ),
								),
								'default' => array(),
								'class' => 'svx-selectize',
								'column' => '2'
							),

							'meta_table' => array(
								'name' => esc_html__( 'List Meta', 'product-loops' ),
								'type' => 'multiselect',
								'desc' => esc_html__( 'Select meta elements to hide in table mode', 'product-loops' ),
								'id'   => 'meta_table',
								'options' => array(
									'sales' => esc_html__( 'Sales', 'product-loops' ),
									'author' => esc_html__( 'Author', 'product-loops' ),
									'date' => esc_html__( 'Date', 'product-loops' ),
									'category' => esc_html__( 'Category', 'product-loops' ),
									'tags' => esc_html__( 'Tag', 'product-loops' ),
									'sku' => esc_html__( 'SKU', 'product-loops' ),
								),
								'default' => array(),
								'class' => 'svx-selectize',
								'column' => '2 last'
							),

							'attributes_grid' => array(
								'name' => esc_html__( 'Grid Attributes', 'product-loops' ),
								'type' => 'multiselect',
								'desc' => esc_html__( 'Select attributes to show in grid mode', 'product-loops' ),
								'id'   => 'attributes_grid',
								'options' => 'ajax:product_attributes',
								'default' => array(),
								'class' => 'svx-selectize',
								'column' => '2'
							),

							'attributes_table' => array(
								'name' => esc_html__( 'List Attributes', 'product-loops' ),
								'type' => 'multiselect',
								'desc' => esc_html__( 'Select attributes to show in table mode', 'product-loops' ),
								'id'   => 'attributes_table',
								'options' => 'ajax:product_attributes',
								'default' => array(),
								'class' => 'svx-selectize',
								'column' => '2 last'
							),

							'column' => array(
								'name' => esc_html__( 'Grid Columns', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Set grid product columns', 'product-loops' ),
								'id'   => 'column',
								'options' => array(
									'1' => '1 ' . esc_html__( 'Column', 'product-loops' ),
									'2' => '2 ' . esc_html__( 'Columns', 'product-loops' ),
									'3' => '3 ' . esc_html__( 'Columns', 'product-loops' ),
									'4' => '4 ' . esc_html__( 'Columns', 'product-loops' ),
									'5' => '5 ' . esc_html__( 'Columns', 'product-loops' ),
									'6' => '6 ' . esc_html__( 'Columns', 'product-loops' ),
									'7' => '7 ' . esc_html__( 'Columns', 'product-loops' ),
									'8' => '8 ' . esc_html__( 'Columns', 'product-loops' ),
									'9' => '9 ' . esc_html__( 'Columns', 'product-loops' ),
									'10' => '10 ' . esc_html__( 'Columns', 'product-loops' ),
								),
								'default' => '3',
								'class' => '',
								'column' => '2'
							),

							'image_width_table' => array(
								'name' => esc_html__( 'List Image Width', 'product-loops' ),
								'type' => 'number',
								'desc' => esc_html__( 'Set the image width in list mode (em)', 'product-loops' ),
								'id'   => 'image_width_table',
								'default' => 15,
								'column' => '2 last'
							),

							'gap' => array(
								'name' => esc_html__( 'Grid Gap', 'product-loops' ),
								'type' => 'select',
								'desc' => esc_html__( 'Set gap between grid columns', 'product-loops' ),
								'id'   => 'gap',
								'options' => array(
									'0' => '0em',
									'1' => '.25em',
									'2' => '.5em',
									'3' => '.75em',
									'4' => '1em',
									'5' => '1.25em',
									'6' => '1.5em',
									'7' => '1.75em',
									'8' => '2em',
									'9' => '2.25em',
									'10' => '2.5em',
									'11' => '2.75em',
									'12' => '3em',
									'13' => '3.25em',
									'14' => '3.5em',
									'15' => '3.75em',
									'16' => '4em',
									'17' => '4.25em',
									'18' => '4.5em',
									'19' => '4.75em',
									'20' => '5em',
								),
								'default' => '3',
								'class' => '',
								'column' => '2 last'
							),

						),
					),

					'wcmn_pl_presets_default_loop' => array(
						'name' => esc_html__( 'Shop Product Loop', 'product-loops' ),
						'type' => 'select',
						'desc' => esc_html__( 'Select shop loop preset', 'product-loops' ),
						'id'   => 'wcmn_pl_presets_default_loop',
						'autoload' => false,
						'options' => 'read:wcmn_pl_presets',
						'default' => '',
						'section' => 'loops',
						'class' => ''
					),

					'wcmn_pl_presets_related_loop' => array(
						'name' => esc_html__( 'Related Product Loop', 'product-loops' ),
						'type' => 'select',
						'desc' => esc_html__( 'Select related loop preset', 'product-loops' ),
						'id'   => 'wcmn_pl_presets_related_loop',
						'autoload' => false,
						'options' => 'read:wcmn_pl_presets',
						'default' => '',
						'section' => 'loops',
						'class' => ''
					),

					'wcmn_pl_presets_upsells_loop' => array(
						'name' => esc_html__( 'Upsells Product Loop', 'product-loops' ),
						'type' => 'select',
						'desc' => esc_html__( 'Select upsells loop preset', 'product-loops' ),
						'id'   => 'wcmn_pl_presets_upsells_loop',
						'autoload' => false,
						'options' => 'read:wcmn_pl_presets',
						'default' => '',
						'section' => 'loops',
						'class' => ''
					),

					'wcmn_pl_presets_cross_sells_loop' => array(
						'name' => esc_html__( 'Cross-Sells Product Loop', 'product-loops' ),
						'type' => 'select',
						'desc' => esc_html__( 'Select cross-sells loop preset', 'product-loops' ),
						'id'   => 'wcmn_pl_presets_cross_sells_loop',
						'autoload' => false,
						'options' => 'read:wcmn_pl_presets',
						'default' => '',
						'section' => 'loops',
						'class' => ''
					),

					'wcmn_pl_overrides' => array(
						'name' => esc_html__( 'Product Loop Overrides', 'product-loops' ),
						'type' => 'hidden',
						'id'   => 'wcmn_pl_overrides',
						'desc' => esc_html__( 'Set loop overrides', 'product-loops' ),
						'autoload' => false,
						'section' => 'hidden',
					),

					'_wcmn_expire_in' => array(
						'name' => esc_html__( 'New Product Loop Period', 'product-loops' ),
						'type' => 'number',
						'id'   => '_wcmn_expire_in',
						'desc' => esc_html__( 'Set new product loop expire in period (days)', 'product-loops' ),
						'autoload' => false,
						'section' => 'loops',
					),

					'_wcmn_expire_in_preset' => array(
						'name' => esc_html__( 'New Product Loop Preset', 'product-loops' ),
						'type' => 'select',
						'id'   => '_wcmn_expire_in_preset',
						'desc' => esc_html__( 'Set new product loop preset', 'product-loops' ),
						'autoload' => false,
						'section' => 'loops',
						'options' => 'read:wcmn_pl_presets'
					),

					'_wcmn_featured' => array(
						'name' => esc_html__( 'Featured Product Loop', 'product-loops' ),
						'type' => 'select',
						'id'   => '_wcmn_featured',
						'desc' => esc_html__( 'Set featured product loop preset', 'product-loops' ),
						'autoload' => false,
						'section' => 'loops',
						'options' => 'read:wcmn_pl_presets'
					),

					'_wcmn_tags' => array(
						'name' => esc_html__( 'Tag Product Loops', 'product-loops' ),
						'type' => 'list',
						'id'   => '_wcmn_tags',
						'desc' => esc_html__( 'Add tag product loop presets', 'product-loops' ),
						'autoload' => false,
						'section' => 'loops',
						'title' => esc_html__( 'Name', 'product-loops' ),
						'options' => 'list',
						'default' => array(),
						'settings' => array(
							'name' => array(
								'name' => esc_html__( 'Name', 'product-loops' ),
								'type' => 'text',
								'id' => 'name',
								'desc' => esc_html__( 'Enter override name', 'product-loops' ),
								'default' => ''
							),
							'term' => array(
								'name' => esc_html__( 'Term', 'product-loops' ),
								'type' => 'select',
								'id'   => 'term',
								'desc' => esc_html__( 'Set override term', 'product-loops' ),
								'options' => 'ajax:taxonomy:product_tag:has_none',
								'default' => ''
							),
							'preset' => array(
								'name' => esc_html__( 'Preset', 'product-loops' ),
								'type' => 'select',
								'id'   => 'preset',
								'desc' => esc_html__( 'Set override preset', 'product-loops' ),
								'options' => 'read:wcmn_pl_presets',
								'default' => ''
							),
						),
					),

					'_wcmn_categories' => array(
						'name' => esc_html__( 'Category Product Loops', 'product-loops' ),
						'type' => 'list',
						'id'   => '_wcmn_categories',
						'desc' => esc_html__( 'Add category product loop presets', 'product-loops' ),
						'autoload' => false,
						'section' => 'loops',
						'title' => esc_html__( 'Name', 'product-loops' ),
						'options' => 'list',
						'default' => array(),
						'settings' => array(
							'name' => array(
								'name' => esc_html__( 'Name', 'product-loops' ),
								'type' => 'text',
								'id' => 'name',
								'desc' => esc_html__( 'Enter override name', 'product-loops' ),
								'default' => '',
							),
							'term' => array(
								'name' => esc_html__( 'Term', 'product-loops' ),
								'type' => 'select',
								'id'   => 'term',
								'desc' => esc_html__( 'Set override term', 'product-loops' ),
								'options' => 'ajax:taxonomy:product_cat:has_none',
								'default' => ''
							),
							'preset' => array(
								'name' => esc_html__( 'Preset', 'product-loops' ),
								'type' => 'select',
								'id'   => 'preset',
								'desc' => esc_html__( 'Set override preset', 'product-loops' ),
								'options' => 'read:wcmn_pl_presets',
								'default' => ''
							),
						),
					),

					/*'wcmn_pl_quickview_elements' => array(
						'name' => esc_html__( 'Elements', 'product-loops' ),
						'type' => 'multiselect',
						'desc' => esc_html__( 'Select quickview elements to hide', 'product-loops' ),
						'id'   => 'wcmn_pl_quickview_elements',
						'options' => array(
							'img' => esc_html__( 'Product Image', 'product-loops' ),
							'ttl' => esc_html__( 'Product Title', 'product-loops' ),
							'dsc' => esc_html__( 'Product Short Description', 'product-loops' ),
							'mta' => esc_html__( 'Product Meta', 'product-loops' ),
							'prc' => esc_html__( 'Product Price', 'product-loops' ),
							'add' => esc_html__( 'Product Add to Cart', 'product-loops' ),
							'qck' => esc_html__( 'Quickview', 'product-loops' ),
						),
						'default' => array(),
						'class' => 'svx-selectize',
						'autoload' => false,
						'section' => 'quickview'
					),*/


					'wcmn_pl_quickview_related' => array(
						'name' => esc_html__( 'Related Products', 'product-loops' ),
						'type' => 'checkbox',
						'desc' => esc_html__( 'Show related products in quick view', 'product-loops' ),
						'id'   => 'wcmn_pl_quickview_related',
						'default' => 'no',
						'autoload' => false,
						'section' => 'quickview'
					),

					'wcmn_pl_presets_quickview_related_loop' => array(
						'name' => esc_html__( 'Related Product Loop', 'product-loops' ),
						'type' => 'select',
						'desc' => esc_html__( 'Select quickview related product loop preset', 'product-loops' ),
						'id'   => 'wcmn_pl_presets_quickview_related_loop',
						'autoload' => false,
						'options' => 'read:wcmn_pl_presets',
						'default' => '',
						'section' => 'quickview'
					),

					'wcmn_pl_presets_quickview_related_limit' => array(
						'name' => esc_html__( 'Related Product Limit', 'product-loops' ),
						'type' => 'number',
						'desc' => esc_html__( 'Select quickview related product limit', 'product-loops' ),
						'id'   => 'wcmn_pl_presets_quickview_related_limit',
						'autoload' => false,
						'default' => '4',
						'section' => 'quickview'
					),

					'wcmn_pl_isotope' => array(
						'name' => esc_html__( 'Isotope Mode', 'product-loops' ),
						'type' => 'select',
						'desc' => esc_html__( 'Isotope.js library settings', 'product-loops' ),
						'id'   => 'wcmn_pl_isotope',
						'options' => array(
							'disable' => esc_html__( 'Disable library and use CSS layout mode', 'product-loops' ),
							'packery' => esc_html__( 'Packery', 'product-loops' ),
							'masonry' => esc_html__( 'Masonry (Default)', 'product-loops' ),
							'fitRows' => esc_html__( 'Fit Rows', 'product-loops' ),

						),
						'default' => 'packery',
						'autoload' => false,
						'section' => 'installation'
					),

					'wcmn_pl_session' => array(
						'name' => esc_html__( 'Grid/List Session', 'product-loops' ),
						'type' => 'checkbox',
						'desc' => esc_html__( 'Remember if users switch grid to list view and vice versa', 'product-loops' ),
						'id'   => 'wcmn_pl_session',
						'default' => 'no',
						'autoload' => false,
						'section' => 'installation'
					),

				)
			);

			foreach ( $plugins['product_loops']['settings'] as $k => $v ) {
				$get = isset( $v['translate'] ) ? $v['id'] . SevenVX()->language() : $v['id'];
				$std = isset( $v['default'] ) ?  $v['default'] : '';
				$set = ( $set = get_option( $get, false ) ) === false ? $std : $set;
				$plugins['product_loops']['settings'][$k]['val'] = SevenVX()->stripslashes_deep( $set );
			}

			return apply_filters( 'wc_productloops_settings', $plugins );
		}

		public static function stripslashes_deep( $value ) {
			$value = is_array($value) ? array_map('stripslashes_deep', $value) : stripslashes($value);
			return $value;
		}

	}

	if ( isset($_GET['page'], $_GET['tab']) && ($_GET['page'] == 'wc-settings' ) && $_GET['tab'] == 'product_loops' ) {
		add_action( 'init', array( 'WC_Product_Loops_Settings', 'init' ), 100 );
		add_filter( 'svx_plugins_settings', array( 'WC_Product_Loops_Settings', 'get_settings' ), 50 );
	}


?>