<?php
/*
Plugin Name: Product Loops for WooCommerce
Plugin URI: https://www.mihajlovicnenad.com/product-loops-woocommerce
Description: Product Loops for WooCommerce! - mihajlovicnenad.com
Author: Mihajlovic Nenad
Version: 1.1.5
Requires at least: 4.5
Tested up to: 4.9.8
WC requires at least: 3.0.0
WC tested up to: 3.5.1
Author URI: https://www.mihajlovicnenad.com
Text Domain: product-loops
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$GLOBALS['svx'] = isset( $GLOBALS['svx'] ) && version_compare( $GLOBALS['svx'], '1.0.9') == 1 ? $GLOBALS['svx'] : '1.0.9';

if ( !class_exists( 'WC_Product_Loops_Init' ) ) :

	final class WC_Product_Loops_Init {

		public static $version = '1.1.5';

		protected static $_instance = null;

		public static function instance() {

			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function __construct() {
			do_action( 'wcmnpl_loading' );

			$this->includes();

			$this->init_hooks();

			do_action( 'wcmnpl_loaded' );
		}

		private function init_hooks() {
			add_action( 'init', array( $this, 'init' ), 0 );
			add_action( 'init', array( $this, 'load_svx' ), 100 );
			add_action( 'plugins_loaded', array( $this, 'fix_svx' ), 100 );
		}

		public function fix_svx() {
			include_once ( 'includes/svx-settings/svx-fixoptions.php' );
		}

		public function load_svx() {
			if ( $this->is_request( 'admin' ) ) {
				include_once ( 'includes/svx-settings/svx-settings.php' );
			}
		}

		private function is_request( $type ) {
			switch ( $type ) {
				case 'admin' :
					return is_admin();
				case 'ajax' :
					return defined( 'DOING_AJAX' );
				case 'cron' :
					return defined( 'DOING_CRON' );
				case 'frontend' :
					return ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' );
			}
		}

		public function includes() {

			if ( $this->is_request( 'admin' ) ) {

				include_once ( 'includes/pl-composer.php' );
				include_once ( 'includes/pl-settings.php' );

			}

			/*if ( $this->is_request( 'frontend' ) ) {*/
				$this->frontend_includes();
			/*}*/

		}

		public function frontend_includes() {
			include_once( 'includes/pl-frontend.php' );
			include_once( 'includes/pl-shortcodes.php' );
		}

		public function init() {

			do_action( 'before_wcmnpl_init' );

			$this->load_plugin_textdomain();

			do_action( 'after_wcmnpl_init' );

		}

		public function load_plugin_textdomain() {

			$domain = 'product-loops';
			$dir = untrailingslashit( WP_LANG_DIR );
			$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

			if ( $loaded = load_textdomain( $domain, $dir . '/plugins/' . $domain . '-' . $locale . '.mo' ) ) {
				return $loaded;
			}
			else {
				load_plugin_textdomain( $domain, FALSE, basename( dirname( __FILE__ ) ) . '/lang/' );
			}

		}

		public function plugin_url() {
			return untrailingslashit( plugins_url( '/', __FILE__ ) );
		}

		public function plugin_path() {
			return untrailingslashit( plugin_dir_path( __FILE__ ) );
		}

		public function plugin_basename() {
			return untrailingslashit( plugin_basename( __FILE__ ) );
		}

		public function ajax_url() {
			return admin_url( 'admin-ajax.php', 'relative' );
		}

		public static function version_check( $version = '3.0.0' ) {
			if ( class_exists( 'WooCommerce' ) ) {
				global $woocommerce;
				if( version_compare( $woocommerce->version, $version, ">=" ) ) {
					return true;
				}
			}
			return false;
		}

		public function version() {
			return self::$version;
		}

	}

	add_filter( 'svx_plugins', 'svx_product_loops_add_plugin', 45 );
	add_filter( 'svx_plugins_settings_short', 'svx_product_loops_add_short' );

	function svx_product_loops_add_plugin( $plugins ) {

		$plugins['product_loops'] = array(
			'slug' => 'product_loops',
			'name' => esc_html__( 'Product Loops', 'product-loops' )
		);

		return $plugins;

	}
	function svx_product_loops_add_short( $plugins ) {
		$plugins['product_loops'] = array(
			'slug' => 'product_loops',
			'settings' => array(

				'wcmn_pl_presets' => array(
					'autoload' => false,
				),

				'wcmn_pl_presets_default_loop' => array(
					'autoload' => false,
				),

				'wcmn_pl_presets_related_loop' => array(
					'autoload' => false,
				),

				'wcmn_pl_presets_upsells_loop' => array(
					'autoload' => false,
				),

				'wcmn_pl_presets_cross_sells_loop' => array(
					'autoload' => false,
				),

				'wcmn_pl_overrides' => array(
					'autoload' => false,
				),

				'wcmn_pl_quickview_related' => array(
					'autoload' => false,
				),

				'wcmn_pl_presets_quickview_related_loop' => array(
					'autoload' => false,
				),

				'wcmn_pl_presets_quickview_related_limit' => array(
					'autoload' => false,
				),

				'wcmn_pl_isotope' => array(
					'autoload' => false,
				),

				'wcmn_pl_session' => array(
					'autoload' => false,
				),

				'wcmn_pl_less' => array(
					'autoload' => true,
				),

			)
		);

		return $plugins;
	}

	function Wcmnpl() {
		return WC_Product_Loops_Init::instance();
	}

	WC_Product_Loops_Init::instance();

endif;

?>